==> activity-center-api-3.5.58-p1-20230614.024154-18-sources.jar: cn/com/duiba/activity/center/api/domain/dto/singleAward/SingleAwardConfigDto.java <==
package cn.com.duiba.activity.center.api.domain.dto.singleAward;

import cn.com.duiba.activity.center.api.dto.activity.OperatingActivityOptionsDto;

import java.util.Date;
import java.io.Serializable;
import java.util.List;

/**
* 发奖活动工具
*/
public class SingleAwardConfigDto  implements Serializable {

    private static final long serialVersionUID = 8065426618925769915L;


    /**
    * id
    */
    private Long id;

    /**
    * appId
    */
    private Long appId;

    /**
     * 入库活动id
     */
    private Long operatingActivityId;

    /**
    * 活动标题
    */
    private String title;

    /**
    * 活动规则
    */
    private String activityRule;

    /**
    * 活动开始时间
    */
    private Date startTime;

    /**
    * 活动结束时间
    */
    private Date endTime;

    /**
     * banner图
     */
    private String bannerImage;

    /**
     * 缩略图
     */
    private String smallImage;

    /**
    * 投放渠道
    */
    private String channel;

    /**
    * 限制用户领取，0-不限制，1-限制
    */
    private Integer receiveLimit;

    /**
    * 可领取次数
    */
    private Long canReceiveNum;

    /**
    * 领取周期：forever-永久，month-自然月，week-自然周，day-每天
    */
    private String receiveType;

    /**
    * 是否需要支付，0-不需要支付，1-需要支付
    */
    private Integer needPay;

    /**
    * 支付金额
    */
    private Long payAmount;

    /**
    * 是否返还支付金额，0-不返还，1-返还
    */
    private Integer needRefundAmount;

    /**
    * 是否限制卡类型，0-不限制，1-限制
    */
    private Integer needLimitCard;

    /**
    * 限制卡类型
    */
    private String limitCard;

    /**
    * 界面配置
    */
    private String interfaceConfig;

    /**
     * 奖品
     */
    private List<SingleAwardOptionDto> optionList;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setActivityRule(String activityRule) {
        this.activityRule = activityRule;
    }

    public String getActivityRule() {
        return activityRule;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannel() {
        return channel;
    }

    public void setReceiveLimit(Integer receiveLimit) {
        this.receiveLimit = receiveLimit;
    }

    public Integer getReceiveLimit() {
        return receiveLimit;
    }

    public void setCanReceiveNum(Long canReceiveNum) {
        this.canReceiveNum = canReceiveNum;
    }

    public Long getCanReceiveNum() {
        return canReceiveNum;
    }

    public void setReceiveType(String receiveType) {
        this.receiveType = receiveType;
    }

    public String getReceiveType() {
        return receiveType;
    }

    public void setNeedPay(Integer needPay) {
        this.needPay = needPay;
    }

    public Integer getNeedPay() {
        return needPay;
    }

    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    public Long getPayAmount() {
        return payAmount;
    }

    public void setNeedRefundAmount(Integer needRefundAmount) {
        this.needRefundAmount = needRefundAmount;
    }

    public Integer getNeedRefundAmount() {
        return needRefundAmount;
    }

    public void setNeedLimitCard(Integer needLimitCard) {
        this.needLimitCard = needLimitCard;
    }

    public Integer getNeedLimitCard() {
        return needLimitCard;
    }

    public void setLimitCard(String limitCard) {
        this.limitCard = limitCard;
    }

    public String getLimitCard() {
        return limitCard;
    }

    public void setInterfaceConfig(String interfaceConfig) {
        this.interfaceConfig = interfaceConfig;
    }

    public String getInterfaceConfig() {
        return interfaceConfig;
    }

    public List<SingleAwardOptionDto> getOptionList() {
        return optionList;
    }

    public void setOptionList(List<SingleAwardOptionDto> optionList) {
        this.optionList = optionList;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> activity-center-api-3.6.25-sources.jar: cn/com/duiba/activity/center/api/domain/dto/singleAward/SingleAwardConfigDto.java <==
package cn.com.duiba.activity.center.api.domain.dto.singleAward;

import cn.com.duiba.activity.center.api.dto.activity.OperatingActivityOptionsDto;

import java.util.Date;
import java.io.Serializable;
import java.util.List;

/**
* 发奖活动工具
*/
public class SingleAwardConfigDto  implements Serializable {

    private static final long serialVersionUID = 8065426618925769915L;


    /**
    * id
    */
    private Long id;

    /**
    * appId
    */
    private Long appId;

    /**
     * 入库活动id
     */
    private Long operatingActivityId;

    /**
    * 活动标题
    */
    private String title;

    /**
    * 活动规则
    */
    private String activityRule;

    /**
    * 活动开始时间
    */
    private Date startTime;

    /**
    * 活动结束时间
    */
    private Date endTime;

    /**
     * banner图
     */
    private String bannerImage;

    /**
     * 缩略图
     */
    private String smallImage;

    /**
    * 投放渠道
    */
    private String channel;

    /**
    * 限制用户领取，0-不限制，1-限制
    */
    private Integer receiveLimit;

    /**
    * 可领取次数
    */
    private Long canReceiveNum;

    /**
    * 领取周期：forever-永久，month-自然月，week-自然周，day-每天
    */
    private String receiveType;

    /**
    * 是否需要支付，0-不需要支付，1-需要支付
    */
    private Integer needPay;

    /**
    * 支付金额
    */
    private Long payAmount;

    /**
    * 是否返还支付金额，0-不返还，1-返还
    */
    private Integer needRefundAmount;

    /**
    * 是否限制卡类型，0-不限制，1-限制
    */
    private Integer needLimitCard;

    /**
    * 限制卡类型
    */
    private String limitCard;

    /**
    * 界面配置
    */
    private String interfaceConfig;

    /**
     * 奖品
     */
    private List<SingleAwardOptionDto> optionList;

    /**
     * 是否发布
     */
    private boolean publish;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setActivityRule(String activityRule) {
        this.activityRule = activityRule;
    }

    public String getActivityRule() {
        return activityRule;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannel() {
        return channel;
    }

    public void setReceiveLimit(Integer receiveLimit) {
        this.receiveLimit = receiveLimit;
    }

    public Integer getReceiveLimit() {
        return receiveLimit;
    }

    public void setCanReceiveNum(Long canReceiveNum) {
        this.canReceiveNum = canReceiveNum;
    }

    public Long getCanReceiveNum() {
        return canReceiveNum;
    }

    public void setReceiveType(String receiveType) {
        this.receiveType = receiveType;
    }

    public String getReceiveType() {
        return receiveType;
    }

    public void setNeedPay(Integer needPay) {
        this.needPay = needPay;
    }

    public Integer getNeedPay() {
        return needPay;
    }

    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    public Long getPayAmount() {
        return payAmount;
    }

    public void setNeedRefundAmount(Integer needRefundAmount) {
        this.needRefundAmount = needRefundAmount;
    }

    public Integer getNeedRefundAmount() {
        return needRefundAmount;
    }

    public void setNeedLimitCard(Integer needLimitCard) {
        this.needLimitCard = needLimitCard;
    }

    public Integer getNeedLimitCard() {
        return needLimitCard;
    }

    public void setLimitCard(String limitCard) {
        this.limitCard = limitCard;
    }

    public String getLimitCard() {
        return limitCard;
    }

    public void setInterfaceConfig(String interfaceConfig) {
        this.interfaceConfig = interfaceConfig;
    }

    public String getInterfaceConfig() {
        return interfaceConfig;
    }

    public List<SingleAwardOptionDto> getOptionList() {
        return optionList;
    }

    public void setOptionList(List<SingleAwardOptionDto> optionList) {
        this.optionList = optionList;
    }

    public boolean isPublish() {
        return publish;
    }

    public void setPublish(boolean publish) {
        this.publish = publish;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}
